@@ -103,10 +103,7 @@ import           Data.Monoid ((<>))
 import           Data.Proxy
 import           Generics.SOP as SOP
 import           Generics.SOP.GGP as SOP
-
-#if MIN_VERSION_generics_sop(0,2,0)
 import           Generics.SOP.Constraint as SOP
-#endif
 
 #if !MIN_VERSION_base(4,8,0)
 import           Data.Foldable (Foldable)
@@ -263,11 +260,7 @@ class HasStructuralInfo a where
   default structuralInfo :: ( GHC.Generic a
                             , All2 HasStructuralInfo (GCode a)
                             , GDatatypeInfo a
-#if MIN_VERSION_generics_sop(0,2,0)
                             , SListI2 (GCode a)
-#else
-                            , SingI (GCode a)
-#endif
                             ) => Proxy a -> StructuralInfo
   structuralInfo = ghcStructuralInfo
 
@@ -294,11 +287,7 @@ structuralInfoSha1ByteStringDigest = bytestringDigest . structuralInfoSha1Digest
 ghcStructuralInfo :: ( GHC.Generic a
                      , All2 HasStructuralInfo (GCode a)
                      , GDatatypeInfo a
-#if MIN_VERSION_generics_sop(0,2,0)
                      , SListI2 (GCode a)
-#else
-                     , SingI (GCode a)
-#endif
                      )
                   => Proxy a
                   -> StructuralInfo
@@ -316,16 +305,12 @@ sopStructuralInfo :: forall a. (Generic a, HasDatatypeInfo a, All2 HasStructural
 sopStructuralInfo proxy = sopStructuralInfoS (datatypeInfo proxy)
 
 sopStructuralInfoS :: forall xss. ( All2 HasStructuralInfo xss
-#if MIN_VERSION_generics_sop(0,2,0)
                                   , SListI2 xss
-#else
-                                  , SingI xss
-#endif
                                   )
                    => DatatypeInfo xss
                    -> StructuralInfo
 sopStructuralInfoS di@(Newtype _ _ ci)  = NominalNewtype (datatypeName di) (sopNominalNewtype ci)
-sopStructuralInfoS di@(ADT _ _ _)       = StructuralInfo (datatypeName di) (sopNominalAdtPOP (hpure Proxy :: POP Proxy xss))
+sopStructuralInfoS di@ADT {}            = StructuralInfo (datatypeName di) (sopNominalAdtPOP (hpure Proxy :: POP Proxy xss))
 
 sopNominalNewtype :: forall x. HasStructuralInfo x => ConstructorInfo '[x] -> StructuralInfo
 sopNominalNewtype _ = structuralInfo (Proxy :: Proxy x)
@@ -357,12 +342,6 @@ sopStructuralInfo1S nsop di = NominalNewtype (datatypeName di) nsop
 -- SOP helpers
 -------------------------------------------------------------------------------
 
-#if !MIN_VERSION_generics_sop(0,2,3)
-datatypeName :: DatatypeInfo xss -> DatatypeName
-datatypeName (Newtype _ d _)  = d
-datatypeName (ADT _ d _)      = d
-#endif
-
 -- | Interleaving
 --
 -- > 3 | 9  .  .  .  .
@@ -374,7 +353,7 @@ datatypeName (ADT _ d _)      = d
 --
 -- This can be calculated by @f x y = sum ([0..x+y]) + y@
 type Interleave (n :: Nat) (m :: Nat) = SumUpTo (n + m) + m
-type SumUpTo (n :: Nat) = Div2 (n * (n + 1))
+type SumUpTo (n :: Nat) = Div2 (n GHC.TypeLits.* (n + 1))
 type family Div2 (n :: Nat) :: Nat where
   Div2 0 = 0
   Div2 1 = 0
